% Este programa genera dibujos de "curvas de bicicleta" en formato dxf 
% para cortadora de laser. Las medidas estan en mm. 
% El programa usa una libreria de funciones llamada DXFLib, 
% bajada desde 
% https://www.mathworks.com/matlabcentral/fileexchange/33884-dxflib 
%
% Ademas, el programa produce una grafica de Matlab de las
% curvas. 

clear all;clc; close all;

escala=40;  % esta escala da una figura 
            % de aprox 290mm de diam 
            
t=linspace(0,2*pi*(1+1/200),200);  % esto da aprox 1mm de distancia
                                   % de un punto al otro
azul=escala*exp(1i*t);             % un circulo
grad_azul=1i*diff(azul)./diff(t);
eps=.085;                               %el "ancho" de un carril
azul_lado1=azul(1:end-1)+eps*grad_azul;
azul_lado2=azul(1:end-1)-eps*grad_azul;
           
T=@(tt) tan(3*tt/10);
gamma=@(tt) exp(1i*tt).*(7*1i+9*T(tt))./(2*1i-6*T(tt));

t=linspace(0,10*pi*(1+1/1500),1500); % esto da aprox 1mm de un punto al otro
verde=escala*gamma(t);

grad_verde=1i*diff(verde)./diff(t);
eps=.085;
verde_lado1=verde(1:end-1)+eps*grad_verde;
verde_lado2=verde(1:end-1)-eps*grad_verde;

azul_largo=escala*exp(1i*t);
rojo=(verde+azul_largo)/2;



X_verde_lado1=real(verde_lado1)';
Y_verde_lado1=imag(verde_lado1)';

X_verde_lado2=real(verde_lado2)';
Y_verde_lado2=imag(verde_lado2)';

X_azul_lado1=real(azul_lado1)';
Y_azul_lado1=imag(azul_lado1)';

X_azul_lado2=real(azul_lado2)';
Y_azul_lado2=imag(azul_lado2)';

X_rojo_central=real(rojo)';
Y_rojo_central=imag(rojo)';

FID = dxf_open('curvas.dxf');

Z=0*X_verde_lado1;
dxf_polyline(FID,X_verde_lado1,Y_verde_lado1,Z);

Z=0*X_verde_lado2;
dxf_polyline(FID,X_verde_lado2,Y_verde_lado2,Z);

Z=0*X_azul_lado1;
dxf_polyline(FID,X_azul_lado1,Y_azul_lado1,Z);

Z=0*X_azul_lado2;
dxf_polyline(FID,X_azul_lado2,Y_azul_lado2,Z);

Z=0*X_rojo_central;
dxf_polyline(FID,X_rojo_central,Y_rojo_central,Z);

dxf_close(FID);

hold on;

plot(verde_lado1,'green');
plot(verde_lado2,'green');
plot(azul_lado1,'blue');
plot(azul_lado2,'blue');
plot(rojo,'red');
axis([-150 150 -150 150]);
axis equal;




